@@ -13,14 +13,14 @@ pub fn new_logger() -> Logger {
             let decorator = slog_term::PlainDecorator::new(std::io::stdout());
             let drain = slog_term::FullFormat::new(decorator).build().fuse();
             let drain = slog_async::Async::new(drain).chan_size(1000).build().fuse();
-            // let drain = slog_envlogger::new(drain).fuse();
+            let drain = slog_envlogger::new(drain).fuse();
             let drain = Mutex::new(drain).map(slog::Fuse);
             slog::Logger::root(drain, o!())
         }
         LogFormat::Json => {
             let drain = slog_json::Json::new(std::io::stdout()).build().fuse();
             let drain = slog_async::Async::new(drain).chan_size(1000).build().fuse();
-            // let drain = slog_envlogger::new(drain).fuse();
+            let drain = slog_envlogger::new(drain).fuse();
             let drain = Mutex::new(drain).map(slog::Fuse);
             slog::Logger::root(
                 drain,
